unit uProxyModuleInterfaceManager;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, ULBLogger, uCommonTypes;


function getWorker(out AWorker: IGenericWorker): Boolean; stdcall; export;

function Initialize(pConfigFolder: pAnsiChar; ALogger: ILBLogger): Boolean; stdcall; export;

function Finalize(): Boolean; stdcall; export;

var
  // ----------------------------------------------------------------------
  // Variables to initialize in developing time
  Gv_GenericWorkerClass    : TGenericWorkerClass = nil;
  Gv_LibraryName           : AnsiString = '';
  Gv_ConfigurationFileName : AnsiString = '';
  // ----------------------------------------------------------------------

  // ----------------------------------------------------------------------
  // Variables initialized by HttpdProxy
  Gv_ConfigurationFolder   : AnsiString = '';
  Gv_Logger                : ILBLogger = nil;
  // ----------------------------------------------------------------------

implementation


function Initialize(pConfigFolder: pAnsiChar; ALogger: ILBLogger): Boolean; stdcall; export;
begin
  Result := False;

  try
    Gv_Logger := ALogger;

    Gv_ConfigurationFolder := strpas(pConfigFolder);

    if GV_Logger <> nil then
      Gv_Logger.Write(1, PChar(Gv_LibraryName + '.Initialize'), lmt_Info, PChar(Format('Library <%s> initialized', [Gv_LibraryName])), GetProcessID);

    Result := True;

  except
    on E: Exception do
    begin
      if ALogger <> nil then
        ALogger.Write(1, PChar(Gv_LibraryName + '.Initialize'), lmt_Error, PChar(E.Message), GetProcessID);
    end;
  end;
end;


function Finalize(): Boolean; stdcall; export;
begin
  Result := False;

  try
    if Gv_Logger <> nil then
      Gv_Logger.Write(1, PChar(Gv_LibraryName + '.Finalize'), lmt_Debug, 'Finalized', GetProcessID);

    Result := True;

    Gv_Logger := nil;

  except
  end;
end;


function getWorker(out AWorker: IGenericWorker): Boolean; stdcall; export;
var
  _AWorker : TGenericWorker = nil;

begin
  Result := False;
  AWorker := nil;

  try
    if Gv_GenericWorkerClass <> nil then
    begin
      _AWorker := Gv_GenericWorkerClass.Create;
      _AWorker.ConfigurationFolder := Gv_ConfigurationFolder;
      _AWorker.ConfigurationFileName := Gv_ConfigurationFileName;
      _AWorker.Logger := Gv_Logger;

      AWorker := _AWorker as IGenericWorker;
      _AWorker := nil;
      Result := True;
    end
    else begin
      if Gv_Logger <> nil then
        Gv_Logger.Write(1, PChar(Gv_LibraryName + '.getGenericWorker'), lmt_Warning, 'Worker class type not set!', GetProcessID);
    end;

  except
    on E: Exception do
    begin
      if Gv_Logger <> nil then
        Gv_Logger.Write(1, PChar(Gv_LibraryName + '.getGenericWorker'), lmt_Error, PChar(E.Message), GetProcessID);
    end;
  end;

  if _AWorker <> nil then
    _AWorker.Free;
end;


end.

