unit uFrmTestProxy;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls;

type

  { TfrmTestProxy }

  TfrmTestProxy = class(TForm)
    btnHelloEnglish: TButton;
    btnKeepAlive: TButton;
    btnHelloItalian: TButton;
    edURL: TEdit;
    Label1: TLabel;
    procedure btnHelloEnglishClick(Sender: TObject);
    procedure btnHelloItalianClick(Sender: TObject);
    procedure btnKeepAliveClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    procedure SendHelloRequest(LanguageType: Integer);
  public
    { public declarations }
  end;

var
  frmTestProxy: TfrmTestProxy;

implementation

{$R *.lfm}

uses
  uHTTPCommandExecutor, uCommonHTTPStructures, uCommonTypes, ULBLogger;

const
  cLibraryName = 'TestProxy';

{ TfrmTestProxy }

procedure TfrmTestProxy.btnKeepAliveClick(Sender: TObject);
var
  _Command : THTTPCommandBase;
  _Executor : THTTPCommandExecutor;

begin
  _Command := THTTPCommandBase.Create;
  _Command.Lib := HTTP_DummyCommand;

  _Executor := THTTPCommandExecutor.Create(_Command, nil);
  if _Executor.Send(edURL.Text) then
    MessageDlg('Module answer OK', mtInformation, [mbOK], 0)
  else
    MessageDlg('No answer!', mtWarning, [mbOK], 0);

  _Command.Free;
  _Executor.Free;
end;

procedure TfrmTestProxy.btnHelloItalianClick(Sender: TObject);
begin
  Self.SendHelloRequest(1);
end;

procedure TfrmTestProxy.btnHelloEnglishClick(Sender: TObject);
begin
  Self.SendHelloRequest(2);
end;

procedure TfrmTestProxy.FormCreate(Sender: TObject);
var
  _Path : String;

begin
  _Path := IncludeTrailingPathDelimiter(ExtractFilePath(Application.ExeName));

  LBLogger := TLBLogger.Create;
  LBLogger.FilePath := _Path + 'logs';
  LBLogger.FileName := 'TestProxy.log';
  LBLogger.MaxLogLevel := 7;
end;

procedure TfrmTestProxy.FormDestroy(Sender: TObject);
begin
  FreeAndNil(LBLogger);
end;

procedure TfrmTestProxy.SendHelloRequest(LanguageType: Integer);
var
  _Command : THTTPCommandBase;
  _Executor : THTTPCommandExecutor;
  _Request : THTTPRequest;
  _HelloRequest : THTTPHelloRequestParams;
  _HelloAnswer : THTTPHelloAnswer;

begin
  _HelloRequest := THTTPHelloRequestParams.Create;
  _HelloRequest.HelloType := LanguageType;

  _Request := THTTPRequest.Create;
  _Request.Request := '1';
  _Request.setParams(_HelloRequest);
  FreeAndNil(_HelloRequest);

  _Command := THTTPCommandBase.Create;
  _Command.Lib := cLibraryName;
  _Command.setRequest(_Request);
  FreeAndNil(_Request);

  FreeAndNil(_HelloRequest);

  _HelloAnswer := THTTPHelloAnswer.Create;

  _Executor := THTTPCommandExecutor.Create(_Command, _HelloAnswer);
  if _Executor.Send(edURL.Text) then
    MessageDlg(Format('%s:  -  %s', [_HelloAnswer.Language, _HelloAnswer.HelloAnswer]), mtInformation, [mbOK], 0)
  else
    MessageDlg('No answer!', mtWarning, [mbOK], 0);

  _HelloAnswer.Free;
  _Command.Free;
  _Executor.Free;
end;

end.

