unit uTestModuleManager;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, uCommonTypes;

type

  { TTestModuleManager }

  TTestModuleManager = class(TGenericWorker)
    strict private
      function AnswerHello(Params: String): Boolean;
    protected
      function LoadConfiguration(): Boolean; override;
    public
      function CanManageLogin(): Boolean; stdcall; override;
      function getToken(): PChar; stdcall; override;
      function getSessionData(): PChar; stdcall; override;


      function Execute(RequestString: pChar; SessionData: pChar; pRawData: pByte; RawDataLen: Integer): Boolean; stdcall; override;
  end;

implementation

uses
  ULBLogger, uCommonHTTPStructures, uLBUtils;

{ TTestModuleManager }

function TTestModuleManager.AnswerHello(Params: String): Boolean;
var
  _Params      : THTTPHelloRequestParams = nil;
  _HelloAnswer : THTTPHelloAnswer = nil;

begin
  Result := False;

  try
    _Params := THTTPHelloRequestParams.Create;
    if _Params.FillFromJSON(Params) then
    begin

      _HelloAnswer := THTTPHelloAnswer.Create;

      case _Params.HelloType of
        1 : begin
              _HelloAnswer.Language := 'Italian';
              _HelloAnswer.HelloAnswer := 'CIAO MONDO!';
            end;

        2 : begin
              _HelloAnswer.Language := 'English';
              _HelloAnswer.HelloAnswer := 'HELLO WORLD!';
            end;

        else begin
          _HelloAnswer.Language := 'Unknown';
          _HelloAnswer.HelloAnswer := '?!?!??! ;)';
        end;
      end;

      FAnswer.Status := HTTP_AnswerStatusOK;
      FAnswer.LastError := '';
      FAnswer.setData(_HelloAnswer);

      if FLogger <> nil then
        FLogger.Write(7, 'TTestModuleManager.AnswerHello', lmt_Debug, PChar('Error decoding parameters: ' + FAnswer.Data), GetProcessID);

    end
    else begin
      if FLogger <> nil then
        FLogger.Write(7, 'TTestModuleManager.AnswerHello', lmt_Warning, PChar('Answer data: ' + Params), GetProcessID);

      FAnswer.Status := HTTP_AnswerStatusError;
      FAnswer.LastError := Format('Error decoding hello params: <%s>', [Params]);
    end;

  except
    on E: Exception do
    begin
      FAnswer.Status := HTTP_AnswerStatusError;
      FAnswer.LastError := E.Message;
    end;
  end;

  if _HelloAnswer <> nil then
    _HelloAnswer.Free;

  if _Params <> nil then
    _Params.Free;
end;

function TTestModuleManager.LoadConfiguration: Boolean;
begin
  Result := True;
end;

function TTestModuleManager.CanManageLogin: Boolean; stdcall;
begin
  Result := True;
end;

function TTestModuleManager.getToken: PChar; stdcall;
begin
  Result := PChar('A Token here ...');
end;

function TTestModuleManager.getSessionData: PChar; stdcall;
begin
  Result := PChar('Some data here ...');
end;

function TTestModuleManager.Execute(RequestString: pChar; SessionData: pChar; pRawData: pByte; RawDataLen: Integer): Boolean; stdcall;
var
  _Request  : THTTPRequest = nil;
  _sRequest : String;
  _ReqVal   : Integer;

begin
  try
    Result := inherited Execute(RequestString, SessionData, pRawData, RawDataLen);

    if Result then
    begin
      if FLogger <> nil then
        FLogger.Write(5, 'TTestModuleManager.Execute', lmt_Debug, 'Decoding request ...', GetProcessID);

      _Request :=  THTTPRequest.Create;
      _sRequest := strpas(RequestString);

      if _Request.FillFromJSON(_sRequest) then
      begin
        _ReqVal := StrToIntDef(_Request.Request, 0);

        case _ReqVal of
          1 : Result := Self.AnswerHello(_Request.Params);

          else begin
            Result := False;
            FAnswer.Status := HTTP_AnswerStatusError;
            FAnswer.LastError := Format('Unknown request: <%s>', [_Request.Request]);
          end;
        end;

      end
      else begin
        if FLogger <> nil then
          FLogger.Write(1, 'TTestModuleManager.Execute', lmt_Debug, 'Error decoding request!', GetProcessID);

        Result := False;
        FAnswer.Status := HTTP_AnswerStatusError;
        FAnswer.LastError := Format('Error decoding request: <%s>', [_sRequest]);
      end;
    end;

  except
    on E: Exception do
    begin
      Result := False;
      FAnswer.Status := HTTP_AnswerStatusError;
      FAnswer.LastError := E.Message;
    end;
  end;

  if not Result then
    LBLogger.Write(1, 'TTestModuleManager.Execute', lmt_Error, PChar(FAnswer.LastError), GetProcessID);


  if _Request <> nil then
    _Request.Free;
end;

end.

