unit uFrmTestDBConnection;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls, uLBDBConnectionManager;

type

  { TfrmTestDBConnection }

  TfrmTestDBConnection = class(TForm)
    btnCreateConnectionManager: TButton;
    btnExecuteQuery: TButton;
    procedure btnCreateConnectionManagerClick(Sender: TObject);
    procedure btnExecuteQueryClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var CloseAction: TCloseAction);
    procedure FormCreate(Sender: TObject);
  private
    FConnectionManager : TSQLConnectionManager;
  public
    { public declarations }
  end;

var
  frmTestDBConnection: TfrmTestDBConnection;

implementation

{$R *.lfm}

uses
  ULBLogger, DOM, XMLRead, sqldb;

{ TfrmTestDBConnection }

procedure TfrmTestDBConnection.btnCreateConnectionManagerClick(Sender: TObject);
var
  _ConfigFile : String;
  _RootNode : TDOMNode;
  _Doc : TXMLDocument;

begin
  if FConnectionManager = nil then
  begin
    _ConfigFile := ExtractFilePath(Application.ExeName) + 'Config.xml';
    if FileExists(_ConfigFile) then
    begin
      ReadXMLFile(_Doc, _ConfigFile);
      if _Doc <> nil then
      begin
        _RootNode := _Doc.DocumentElement;

        FConnectionManager := TSQLConnectionManager.Create;
        if not FConnectionManager.LoadConfigurationFromXML(_RootNode) then
          FreeAndNil(FConnectionManager);

      end;
    end
    else
      LBLogger.Write(1,'TfrmTestDBConnection.btnCreateConnectionManagerClick', lmt_Warning, PChar(Format('Configuration file <%s> not found!', [_ConfigFile])), GetProcessID);
  end;
end;

procedure TfrmTestDBConnection.btnExecuteQueryClick(Sender: TObject);
var
  _Conn : TSQLConnection;
  _Query : TSQLQuery;

begin
  if FConnectionManager <> nil then
  begin
    _Conn := FConnectionManager.getConnection('DBTest');
    if _Conn <> nil then
    begin
      _Query := TSQLQuery.Create(nil);
      _Query.DataBase := _Conn;

      _Query.SQL.Text := 'SELECT COUNT(*) FROM Transactions;';
      _Query.Open;

      if not (_Query.EOF and _Query.BOF) then
        LBLogger.Write(1,'TfrmTestDBConnection.btnExecuteQueryClick', lmt_Info, PChar(Format('Query executed! Result: %d', [_Query.Fields[0].AsInteger])), GetProcessID);


      _Query.Close;
      FreeAndNil(_Query);

      FConnectionManager.CloseConnection(_Conn);
    end;
  end;
end;

procedure TfrmTestDBConnection.FormClose(Sender: TObject; var CloseAction: TCloseAction);
begin
  CloseAction := caFree;

  if FConnectionManager <> nil then
    FConnectionManager.Free;

  if LBLogger <> nil then
    FreeAndNil(LBLogger);
end;

procedure TfrmTestDBConnection.FormCreate(Sender: TObject);
begin
  LBLogger := TLBLogger.Create;
  LBLogger.FileName := 'Test.log';
  LBLogger.FilePath := ExtractFilePath(Application.ExeName) + 'logs';
  LBLogger.Write(1,'TfrmTestDBConnection.FormCreate', lmt_Info, 'Started ...', GetProcessID);
end;

end.

